@@ -1,6 +1,6 @@
 ##############################################################################
 #
-# Copyright (c) 2002, 2004 Zope Corporation and Contributors.
+# Copyright (c) 2002, 2004 Zope Foundation and Contributors.
 # All Rights Reserved.
 #
 # This software is subject to the provisions of the Zope Public License,
@@ -32,7 +32,7 @@ def bootStrapSubscriber(event):
     db, connection, root, root_folder = getInformationFromEvent(event)
 
     ensureUtility(root_folder, IErrorReportingUtility, '',
-                  RootErrorReportingUtility, copy_to_zlog=False, asObject=True)
+                  RootErrorReportingUtility, copy_to_zlog=True)
 
     transaction.commit()
     connection.close()
